summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendarepoch.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /konsolekalendar/konsolekalendarepoch.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konsolekalendar/konsolekalendarepoch.cpp')
-rw-r--r--konsolekalendar/konsolekalendarepoch.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/konsolekalendar/konsolekalendarepoch.cpp b/konsolekalendar/konsolekalendarepoch.cpp
index 59cd7e91..e314bde7 100644
--- a/konsolekalendar/konsolekalendarepoch.cpp
+++ b/konsolekalendar/konsolekalendarepoch.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -49,23 +49,23 @@ KonsoleKalendarEpoch::~KonsoleKalendarEpoch()
// By "epoch" we mean the number of seconds since 00:00:00 UTC on January 1 1970
-// Function to convert an epoch value into a QDateTime
+// Function to convert an epoch value into a TQDateTime
TQDateTime KonsoleKalendarEpoch::epoch2TQDateTime( uint epoch )
{
TQDateTime dt;
- dt.setTime_t( epoch, Qt::UTC );
+ dt.setTime_t( epoch, TQt::UTC );
return( dt );
}
// Function to convert a TQDateTime value into an epoch
-uint KonsoleKalendarEpoch::QDateTime2epoch( TQDateTime dt )
+uint KonsoleKalendarEpoch::TQDateTime2epoch( TQDateTime dt )
{
// THIS FUNCTION CAN BE OFF BY 1 HOUR DUE TO DAYLIGHT SAVINGS TIME.
// SORRY QT DOESN'T HANDLE DAYLIGHT SAVINGS TIME.
// Compute #seconds to subtract for local timezone difference from UTC.
- int offset = TQDateTime::tqcurrentDateTime( Qt::UTC ).toTime_t()
- - TQDateTime::tqcurrentDateTime( Qt::LocalTime ).toTime_t();
+ int offset = TQDateTime::tqcurrentDateTime( TQt::UTC ).toTime_t()
+ - TQDateTime::tqcurrentDateTime( TQt::LocalTime ).toTime_t();
return( dt.toTime_t() - offset );
}
@@ -90,12 +90,12 @@ main()
cout << "epoch="
<< epoch
<< " converts to "
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< endl;
- epoch = KonsoleKalendarEpoch::QDateTime2epoch( dt );
+ epoch = KonsoleKalendarEpoch::TQDateTime2epoch( dt );
cout << "date="
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< " converts to "
<< "epoch="
<< epoch
@@ -108,12 +108,12 @@ main()
cout << "epoch="
<< epoch
<< " converts to "
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< endl;
- epoch = KonsoleKalendarEpoch::QDateTime2epoch( dt );
+ epoch = KonsoleKalendarEpoch::TQDateTime2epoch( dt );
cout << "date="
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< " converts to "
<< "epoch="
<< epoch
@@ -126,12 +126,12 @@ main()
cout << "epoch="
<< epoch
<< " converts to "
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< endl;
- epoch = KonsoleKalendarEpoch::QDateTime2epoch( dt );
+ epoch = KonsoleKalendarEpoch::TQDateTime2epoch( dt );
cout << "date="
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< " converts to "
<< "epoch="
<< epoch
@@ -144,12 +144,12 @@ main()
cout << "epoch="
<< epoch
<< " converts to "
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< endl;
- epoch = KonsoleKalendarEpoch::QDateTime2epoch( dt );
+ epoch = KonsoleKalendarEpoch::TQDateTime2epoch( dt );
cout << "date="
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< " converts to "
<< "epoch="
<< epoch
@@ -162,12 +162,12 @@ main()
cout << "epoch="
<< epoch
<< " converts to "
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< endl;
- epoch = KonsoleKalendarEpoch::QDateTime2epoch( dt );
+ epoch = KonsoleKalendarEpoch::TQDateTime2epoch( dt );
cout << "date="
- << dt.toString( Qt::TextDate )
+ << dt.toString( TQt::TextDate )
<< " converts to "
<< "epoch="
<< epoch
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/